//#pragma once

//#include "resource.h"

						//////////////////////////////////////////////////////
						//////////////////////////////////////////////////////
						//////                                        ////////
						//////                                        ////////
						//////     ZeeImage Copyright(C) 2020         ////////
						//////                 by                     ////////
						//////            David Hillard               ////////
						//////                                        ////////
						//////                                        ////////
						//////      Contact: david@kycsepp.com        ////////
						//////                                        ////////
						//////////////////////////////////////////////////////
						//////////////////////////////////////////////////////
 

#define ZIM_LOADIMAGE			WM_USER+10  //wParam = (int) slot
											//lParam = filename
											//Return = nothing
											//Example: SendMessage(himage,ZIM_LOADIMAGE,5,(LPARAM)"filepath\\myimage.png");
											//Note:  Will silently fail if specified slot is greater than the number of slots
											//       available.  In the beta version of the control, there are 100 slots (0-99)
											//       If the specified slot already has an image loaded into it, it will be 
											//       replaced with this specified image.  The control takes care of performing 
											//       the DeleteObject((HBITMAP)) for you.

#define ZIM_SETEXPAND			WM_USER+11  //wParam = (int) slot
											//lParam = (BOOL) EXPAND
											//Return = nothing
											//Example: SendMessage(himage,ZIM_LOADIMAGEMT,5,TRUE);
											//Note:  If image is smaller in dimensions than client area, this toggle determines if the 
											//       image is shown as original size or is expanded to fill the client area

#define ZIM_SETTRANSPARENTCOLOR WM_USER+12  //wParam = not used
											//lParam = (COLORREF)
											//Return = nothing
											//Example: SendMessage(himage,ZIM_SETTRANSPARENTCOLOR,0,RGB(255,255,0));
											//Note:  Transparent colors are only used with image files that support an alpha channel. (png and tif)
											//       The control will default to a tranparent color of white (RGB(255,255,255)).  
											//       The transparency is only in effect when the image is loaded with ZIM_LOADIMAGE.
											//       Once the tranparency color is set, it will remain in effect until changed again 
											//       with ZIM_SETTRANSPARENTCOLOR.  The transparency color is a global attribute and sticky.

#define ZIM_SETBGCOLOR			WM_USER+13  //wParam = (int) slot
											//lParam = (COLORREF)
											//Return = nothing
											//Example: SendMessage(himage,ZIM_SETBGCOLOR,3,RGB(0,0,255));
											//Note:  The image control automatically sizes the image to keep the aspect ratio constant.
											//       Depending on the size of the image control, it will letterbox the image and the
											//       background color is the color that the letterbox border is painted. The default background
											//       color is white (RGB(255,255,255)).

#define ZIM_DISPLAYIMAGE		WM_USER+14  //wParam = (int) slot
											//lParam = not used
											//Return = nothing
											//Example:  SendMessage(himage,ZIM_DISPLAYIMAGE,7,0);
											//Note:  The image control can use this message to immediately display any image loaded into any slot.
											//       If a slot is displayed that doesn't have an image loaded into it, it will just be blank.

#define ZIM_GETCURRENTIMAGE		WM_USER+15  //wParam = not used
											//lParam = not used
											//Return = (int) slot of currently displayed image.
											//Example:  int ci=SendMessage(himage,ZIM_GETCURRENTIMAGE,0,0);
											//Note:  If slot 3 does not have an image loaded into it, and slot 3 is the currently displayed 
											//       image (blank), 3 will still be returned even though there's no image in it.

#define ZIM_CLEARALL			WM_USER+16  //wParam = not used
											//lParam = not used
											//Return = nothing
											//Example:  SendMessage(himage,ZIM_CLEARALL,0,0);
											//Note:  This message removes all loaded images from the control and performs the necessary housekeeping
											//       to DeleteObject(HBITMAP) for all loaded images.

#define ZIM_GETIMAGEWIDTH		WM_USER+17  //wParam = (int) slot
											//lParam = not used
											//Return = (int) width of image in pixels for the specified slot.  
											//Example:  int width=SendMessage(himage,ZIM_GETIMAGEWIDTH,10,0);
											//Note:  Will return 0 if no image is loaded in specified slot.

#define ZIM_GETIMAGEHEIGHT		WM_USER+18  //wParam = (int) slot
											//lParam = not used
											//Return = (int) height of image in pixels for the specified slot.  
											//Example:  int height=SendMessage(himage,ZIM_GETIMAGEHEIGHT,10,0);
											//Note:  Will return 0 if no image is loaded in specified slot.

#define ZIM_SETANIMATELOOP		WM_USER+21  //wParam = (int) number_of_times_to_loop animation (-1 for infinite, 0 for no loop or play once, 1 for loop once or play twice, etc.)
											//lParam = not used
											//Return = nothing
											//Example:  SendMessage(himage,ZIM_SETANIMATELOOP,2,0);
											//Note:  The value in wParam is how many times the animation loops, which is one less than how many times it plays.
											//       This value is global and sticky for the control.  It defaults to -1 meaning the animation will loop forever.
											//       Set the loop value before starting the animation.

#define ZIM_SETANIMATEDELAY		WM_USER+22  //wParam = (int) milliseconds delay between images
											//lParam = not used
											//Return = nothing
											//Example:  SendMessage(himage,ZIM_SETANIMATEDELAY,33,0);
											//Note:  To get the value for a particular FPS (frames per second), use the integer value of 1000/desired_FPS.
											//       The value of 33 in the example will give an animation framerate of roughly 30 frames per second. 

#define ZIM_STARTANIMATE		WM_USER+23  //wParam = (int) start_slot
											//lParam = (int) end_slot
											//Return = nothing
											//Example:  SendMessage(himage,ZIM_STARTANIMATE,2,10);
											//Note:  The end slot must be greater than the start slot, and both values must be between 0 and 10 inclusive.
											//       This message will start the animation to be determined by the number of loops and the FPS previously set with
											//       ZIM_SETANIMATELOOP and ZIM_SETANIMATEDELAY

#define ZIM_STOPANIMATE			WM_USER+24  //wParam = not used
											//lParam = not used
											//Return = nothing
											//Example:  SendMessage(himage,ZIM_STOPANIMATE,0,0);
											//Note:  Stops the animation if it's running.  If it's not animating, this has no effect.

#define ZIM_GETBITMAP			WM_USER+25  //wParam = (int) slot
											//lParam = not used
											//Return = (HBITMAP) or 0 if no image is loaded in specified slot.
											//Example: HBITMAP bm;
											//         bm=(HBITMAP)SendMessage(himage,ZIM_GETBITMAP,4,0);
											//Note:  In this example, the handle to the bitmap (bm) is ready to be used by selecting it into a device context
											//       with SelectObject().   Don't forget to select it out of the device context when finished with it.
											//       Do not execute a DeleteObject on it.  The image control "owns" it.

#define ZIM_SETDIVISOR			WM_USER+26  //wParam = (int) divisor
											//lParam = not used
											//Return = nothing
											//Example:  SendMessage(himage,ZIM_SETDIVISOR,3,0);
											//Note:  The divisor is a global/sticky variable.  It determines the resolution of the imported image.  The control
											//       defaults to a divisor value of 1.  If the image being loaded has a resolution of 1600x900, setting the divisor
											//       to 2 will load the image with a resolution of 800x450.  The ZIM_LOADIMAGE message will use the current divisor value.
											//       This can be used to save memory when a high resolution image will only be displayed in a relatively small area on the screen.
 

/////////////////////////////////////////////////////
//////                                         //////
//////       Notification Messages             //////
//////                                         //////
/////////////////////////////////////////////////////

#define ZIN_BETAEXPIRED			WM_USER+201 //